# ABSTRACT: ** Please provide abstract **

package Form::Processor::I18N;
{
  $Form::Processor::I18N::VERSION = '1.122970';
}
use strict;
use warnings;
use base qw(Locale::Maketext);

1;



__END__
=pod

=head1 NAME

Form::Processor::I18N - ** Please provide abstract **

=head1 VERSION

version 1.122970

=head1 AUTHOR

Bill Moseley <mods@hank.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Bill Moseley.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

